"""Display and logging functionality."""

import logging

from fastapi import FastAPI

from mockstack.config import Settings


def announce(app: FastAPI, settings: Settings):
    """Log the startup message with the active settings."""
    logger = logging.getLogger("uvicorn")
    extra = {"markup": True}

    logger.info(
        f"[bold medium_purple]mockstack[/bold medium_purple] ready to roll. "
        f"debug: [medium_purple]{settings.debug}[/medium_purple]. "
        f"strategy: [medium_purple]{settings.strategy}[/medium_purple]. ",
        extra=extra,
    )
    logger.info(str(app.state.strategy), extra=extra)
    logger.info(
        f"OpenTelemetry enabled: [medium_purple]{settings.opentelemetry.enabled}[/medium_purple], "
        f"endpoint: [medium_purple]{settings.opentelemetry.endpoint}[/medium_purple], "
        f"capture_response_body: [medium_purple]{settings.opentelemetry.capture_response_body}[/medium_purple]",
        extra=extra,
    )
